$header "const char * const chkr_errlist[]"
$declare "const char * const chkr_errlist[];"

E_UNKNOWN	"Unknown error"
E_FREEFBLOCK	"Try to free a free block"
E_FREEFFRAG	"Try to free a free fragment"
E_BADADDR	"This address hadn't been returned by malloc"
E_NULLBSIZE	"Free a block which null size"
E_FREEBMALLOC	"free is called before malloc"
E_BADRDSIZE	"Length of a red zone is bad"
E_CALLBRK	"brk() was directly called"
E_BADBYTEPS	"'bytes_per_state' is 0. Use default value"
E_MEMACCERR	"Memory access error"
E_IE_BRIGHT	"Internal error: bad right while checking"
E_IE_INSTUK	"Internal error: instruction unknown"
E_IE_BSYSCALL	"Internal error: can't check this syscall"
E_BAD_FD	"Try to use a fd reserved by Checker"
E_BAD_SFD	"The system has returned a fd reserved by Checker"
E_BAD_SBRK	"Try to free memory through sbrk/brk"
E_NOT_RECURS	"Checker V0.5 is not recursive!!"
E_OUT_OF_SMEM	"Out of system memory!!"
E_OUT_OF_MEM	"Warning: virtual memory exceeded."
